//***************************************************************************************
// "Evaluating the Macroeconomic Effects of the ECB’s Unconventional Monetary Policy "
//
// By Sarah Mouabbi and Jean-Guillaume Sahuc
//
// Counterfactual exercise
//
//**************************************************************************************


@#include "dsge_shadow_ea_9917_0.mod". // same file as "dsge_shadow_ea_9917.mod" but without the estimation block at the end

varobs dyobs dcobs dxobs dwobs inflobs srobs srobs2 srobs3 dhoursobs;

c_dyobs_4_true_bayes    = [] ; c_dyobs_4_count_bayes   = [];  c_inflobs_4_true_bayes = []; c_inflobs_4_count_bayes = [];
c_dyobs_1_true_bayes   = []; c_dyobs_1_count_bayes   = []; c_inflobs_1_true_bayes  = []; c_inflobs_1_count_bayes = [];
 c_dyobs_bayes = []; c_dyobs_count_bayes = []; c_dcobs_bayes = []; c_dcobs_count_bayes = [];
c_dxobs_bayes = []; c_dxobs_count_bayes = []; c_inflobs_bayes = []; c_inflobs_count_bayes = []; 
c_dwobs_bayes = []; c_dwobs_count_bayes = []; c_dhoursobs_bayes       = []; c_dhoursobs_count_bayes = [];

res_srobs = load('dsge_shadow_ea_9917_results'); // load the dynare results file after the estimation
load dsge_shadow_ea_9917_simul; // draw in the estimated parameters distribution obtained after the estimation to create as many variables paths you want, them save them and load this results file
 
database = load('euro_data_17Q2');
 
sample = 2008:0.25:2017.25; 
 
initdate = 36;
 
plotgraph = 0;


for jj=1:1:10000;

res_srobs.oo_.SmoothedVariables = SmoothedVariables_bayes(:,jj);
res_srobs.oo_.SmoothedShocks    = SmoothedShocks_bayes(:,jj);
res_srobs.oo_.dr                =dr_bayes(:,jj);
 
//************************************************************
//Reproducing the smoothed variables of the shadow rate model
//************************************************************
 
y0 = zeros(M_.endo_nbr,1);
for i=1:M_.endo_nbr;
  y0(i) = res_srobs.oo_.SmoothedVariables.(M_.endo_names{i})(1);
end;
 
horizon = length(res_srobs.oo_.SmoothedShocks.(M_.exo_names{1}));
xx = zeros(horizon+1,M_.exo_nbr);
for i=1:M_.exo_nbr;
  xx(1:end-2,i) = res_srobs.oo_.SmoothedShocks.(M_.exo_names{i})(2:end)';
end;
        
ysmoothed_sr = simult_(y0,res_srobs.oo_.dr,xx,1);
for i = 1:length(options_.varobs);
  name = options_.varobs{i};
  idx1 = strmatch(name,M_.endo_names,'exact');
  //disp(norm(ysmoothed_sr(idx1,1:end-2)' - database.(name)(1:end)));
end;                         
order_var = res_srobs.oo_.dr.order_var;
i_srobs_1 = strmatch('r',M_.endo_names,'exact'); 
i_srobs_2 = strmatch('r',M_.endo_names(order_var),'exact');
i_srobs_22 = strmatch('srobs',M_.endo_names(order_var),'exact');
 
//********************************************************
//Counterfactual: the central bank follows the Eonia rate
//********************************************************
 
 
A = res_srobs.oo_.dr.ghx;
B = res_srobs.oo_.dr.ghu;
ys = res_srobs.oo_.dr.ys(order_var);
i_state = M_.nstatic + (1:M_.nspred);
xx_1 = xx;
 
n = length(database.srobs);
yy_1 = zeros(M_.endo_nbr,n+1);
yy_1(:,1) = y0(order_var) - ys;
for i = 2:n;
    // compute monetary policy shock (zetar) consistent with robs
    xx_1(i-1,6) = (database.robs2(i) - ys(i_srobs_22) - A(i_srobs_2,:)*yy_1(i_state,i-1) - B(i_srobs_2,[1:5 7])*xx_1(i-1,[1:5 7])')/B(i_srobs_2,6);  
    // compute one period ahead
    yy_1(:,i) = A*yy_1(i_state,i-1) + B*xx_1(i-1,:)';
end;
 
yy_1 = yy_1 + repmat(ys,1,size(yy_1,2));
ysmoothed_r(order_var,:) = yy_1;
 
i_dyobs = strmatch('dyobs',M_.endo_names,'exact');
i_dcobs = strmatch('dcobs',M_.endo_names,'exact');
i_dxobs = strmatch('dxobs',M_.endo_names,'exact');
i_dwobs = strmatch('dwobs',M_.endo_names,'exact');
i_dhoursobs = strmatch('dhoursobs',M_.endo_names,'exact');
i_inflobs = strmatch('inflobs',M_.endo_names,'exact');
i_infl = strmatch('infl',M_.endo_names,'exact');
i_r = strmatch('r',M_.endo_names,'exact');



srobs_true      = ysmoothed_sr(15,2:end-2)'; robs_count      = ysmoothed_r(15,2:end-1)' ;
inflobs_true    = ysmoothed_sr(5,2:end-2)'; inflobs_count   = ysmoothed_r(5,2:end-1)' ;
dyobs_true      = ysmoothed_sr(1,2:end-2)'; dyobs_count     = ysmoothed_r(1,2:end-1)' ;
dcobs_true      = ysmoothed_sr(2,2:end-2)'; dcobs_count     = ysmoothed_r(2,2:end-1)';
dxobs_true      = ysmoothed_sr(3,2:end-2)'; dxobs_count     = ysmoothed_r(3,2:end-1)' ;
dwobs_true      = ysmoothed_sr(4,2:end-2)'; dwobs_count     = ysmoothed_r(4,2:end-1)' ;
dhoursobs_true  = ysmoothed_sr(9,2:end-2)'; dhoursobs_count = ysmoothed_r(9,2:end-1)';
 
c_dyobs         = cumsum(dyobs_true); c_dyobs_count   = cumsum(dyobs_count);
c_dcobs         = cumsum(dcobs_true); c_dcobs_count   = cumsum(dcobs_count);
c_dxobs         = cumsum(dxobs_true); c_dxobs_count   = cumsum(dxobs_count);
c_inflobs       = cumsum(inflobs_true); c_inflobs_count = cumsum(inflobs_count);
c_dwobs         = cumsum(dwobs_true); c_dwobs_count   = cumsum(dwobs_count);
c_dhoursobs     = cumsum(dhoursobs_true); c_dhoursobs_count = cumsum(dhoursobs_count);
 
c_dyobs_4_true      = c_dyobs(5:end)-c_dyobs(1:end-4); c_dyobs_4_count     = c_dyobs_count(5:end)-c_dyobs_count(1:end-4);
c_inflobs_4_true    = c_inflobs(5:end)-c_inflobs(1:end-4); c_inflobs_4_count   = c_inflobs_count(5:end)-c_inflobs_count(1:end-4);
c_dyobs_1_true      = c_dyobs(2:end)-c_dyobs(1:end-1); c_dyobs_1_count     = c_dyobs_count(2:end)-c_dyobs_count(1:end-1);
c_inflobs_1_true    = c_inflobs(2:end)-c_inflobs(1:end-1); c_inflobs_1_count   = c_inflobs_count(2:end)-c_inflobs_count(1:end-1);
 
c_dyobs = c_dyobs - c_dyobs(initdate) + 100; c_dyobs_count = c_dyobs_count - c_dyobs_count(initdate) + 100;
c_dcobs = c_dcobs - c_dcobs(initdate) + 100; c_dcobs_count = c_dcobs_count - c_dcobs_count(initdate) + 100;
c_dxobs = c_dxobs - c_dxobs(initdate) + 100; c_dxobs_count = c_dxobs_count - c_dxobs_count(initdate) + 100;
c_inflobs = c_inflobs - c_inflobs(initdate) + 100; c_inflobs_count = c_inflobs_count - c_inflobs_count(initdate) + 100;
c_dwobs = c_dwobs - c_dwobs(initdate) + 100; c_dwobs_count = c_dwobs_count - c_dwobs_count(initdate) + 100;
c_dhoursobs = c_dhoursobs - c_dhoursobs(initdate) + 100; c_dhoursobs_count = c_dhoursobs_count - c_dhoursobs_count(initdate) + 100;

c_dyobs_4_true_bayes    = [ c_dyobs_4_true_bayes c_dyobs_4_true] ; c_dyobs_4_count_bayes   = [ c_dyobs_4_count_bayes c_dyobs_4_count] ;
c_inflobs_4_true_bayes  = [ c_inflobs_4_true_bayes c_inflobs_4_true] ; c_inflobs_4_count_bayes = [ c_inflobs_4_count_bayes c_inflobs_4_count] ;
c_dyobs_1_true_bayes    = [ c_dyobs_1_true_bayes c_dyobs_1_true] ; c_dyobs_1_count_bayes   = [ c_dyobs_1_count_bayes c_dyobs_1_count] ;
c_inflobs_1_true_bayes  = [ c_inflobs_1_true_bayes c_inflobs_1_true] ; c_inflobs_1_count_bayes = [ c_inflobs_1_count_bayes c_inflobs_1_count] ;
 
c_dyobs_bayes           = [c_dyobs_bayes c_dyobs] ; c_dyobs_count_bayes     = [c_dyobs_count_bayes c_dyobs_count] ;
c_dcobs_bayes           = [c_dcobs_bayes c_dcobs] ; c_dcobs_count_bayes     = [ c_dcobs_count_bayes c_dcobs_count] ;
c_dxobs_bayes           = [ c_dxobs_bayes  c_dxobs] ; c_dxobs_count_bayes     = [ c_dxobs_count_bayes c_dxobs_count] ;
c_inflobs_bayes         = [c_inflobs_bayes c_inflobs] ; c_inflobs_count_bayes   = [c_inflobs_count_bayes c_inflobs_count] ;
c_dwobs_bayes           = [c_dwobs_bayes c_dwobs] ; c_dwobs_count_bayes     = [c_dwobs_count_bayes c_dwobs_count] ;
c_dhoursobs_bayes       = [c_dhoursobs_bayes c_dhoursobs] ; c_dhoursobs_count_bayes = [c_dhoursobs_count_bayes c_dhoursobs_count] ;

end;

c_dyobs_count_bayes_min = min(c_dyobs_count_bayes')'; c_dyobs_count_bayes_max = max(c_dyobs_count_bayes')'; c_dyobs_count_bayes_mean = mean(c_dyobs_count_bayes')';
c_dcobs_count_bayes_min = min(c_dcobs_count_bayes')'; c_dcobs_count_bayes_max = max(c_dcobs_count_bayes')'; c_dcobs_count_bayes_mean = mean(c_dcobs_count_bayes')'; 
c_dxobs_count_bayes_min = min(c_dxobs_count_bayes')'; c_dxobs_count_bayes_max = max(c_dxobs_count_bayes')'; c_dxobs_count_bayes_mean = mean(c_dxobs_count_bayes')';
c_inflobs_count_bayes_min = min(c_inflobs_count_bayes')'; c_inflobs_count_bayes_max = max(c_inflobs_count_bayes')'; c_inflobs_count_bayes_mean = mean(c_inflobs_count_bayes')';
c_dwobs_count_bayes_min = min(c_dwobs_count_bayes')'; c_dwobs_count_bayes_max = max(c_dwobs_count_bayes')'; c_dwobs_count_bayes_mean = mean(c_dwobs_count_bayes')';
c_dhoursobs_count_bayes_min = min(c_dhoursobs_count_bayes')'; c_dhoursobs_count_bayes_max = max(c_dhoursobs_count_bayes')'; c_dhoursobs_count_bayes_mean = mean(c_dhoursobs_count_bayes')';
c_dyobs_4_count_bayes_min = min(c_dyobs_4_count_bayes')'; c_dyobs_4_count_bayes_max = max(c_dyobs_4_count_bayes')'; c_dyobs_4_count_bayes_mean = mean(c_dyobs_4_count_bayes')';
c_inflobs_4_count_bayes_min = min(c_inflobs_4_count_bayes')'; c_inflobs_4_count_bayes_max = max(c_inflobs_4_count_bayes')'; c_inflobs_4_count_bayes_mean = mean(c_inflobs_4_count_bayes')';
 
CI = [0.16,0.5,0.84];

c_dyobs_4_count_bayes     = quantile(c_dyobs_4_count_bayes',CI); 
c_inflobs_4_count_bayes   = quantile(c_inflobs_4_count_bayes',CI); 


save comfactor_results_compar c_dyobs_4_count_bayes_mean c_inflobs_4_count_bayes_mean c_dyobs_4_true c_inflobs_4_true;


//******************************************************
//Counterfactual: Figures
//******************************************************
 
if plotgraph ==1;
 
subplot(3,3,1)
    plot(sample,c_dyobs(initdate:end),'Linewidth',4,'LineStyle','-','Color',[0., 0., 0.]);
    hold on
    irfplot_y_1([sample]',[c_dyobs_count_bayes_mean(initdate:end)],[c_dyobs_count_bayes_min(initdate:end)],[c_dyobs_count_bayes_max(initdate:end)],'',22);
    hold off
    set(gca,'fontname','times','FontSize',23)
    title('Output','Interpreter','Latex');
    legend({'Observed','Counterfactual','68% confidence interval'},'Location','NorthWest','FontSize',13);
    axis([2008 2018 92 106])
    subplot(3,3,2)
    plot(sample,c_dcobs(initdate:end),'Linewidth',4,'LineStyle','-','Color',[0., 0., 0.]);
    hold on
    irfplot_y_1([sample]',[c_dcobs_count_bayes_mean(initdate:end)],[c_dcobs_count_bayes_min(initdate:end)],[c_dcobs_count_bayes_max(initdate:end)],'',22);
    hold off
    set(gca,'fontname','times','FontSize',23)
    title('Consumption','Interpreter','Latex');
    axis([2008 2018 97 105])
    subplot(3,3,3)
    plot(sample,c_dxobs(initdate:end),'Linewidth',4,'LineStyle','-','Color',[0., 0., 0.]);
    hold on
    irfplot_y_1([sample]',[c_dxobs_count_bayes_mean(initdate:end)],[c_dxobs_count_bayes_min(initdate:end)],[c_dxobs_count_bayes_max(initdate:end)],'',22);
    set(gca,'fontname','times','FontSize',23)
    title('Investment','Interpreter','Latex');
    axis([2008 2018 78 100])
    subplot(3,3,4)
    plot(sample,c_dhoursobs(initdate:end),'Linewidth',4,'LineStyle','-','Color',[0., 0., 0.]);
    hold on
    irfplot_y_1([sample]',[c_dhoursobs_count_bayes_mean(initdate:end)],[c_dhoursobs_count_bayes_min(initdate:end)],[c_dhoursobs_count_bayes_max(initdate:end)],'',22);
    hold off
    set(gca,'fontname','times','FontSize',23)
    title('Hours worked','Interpreter','Latex');
    axis([2008 2018 90 100])
    subplot(3,3,5)
    plot(sample,c_dwobs(initdate:end),'Linewidth',4,'LineStyle','-','Color',[0., 0., 0.]);
    hold on
    irfplot_y_1([sample]',[c_dwobs_count_bayes_mean(initdate:end)],[c_dwobs_count_bayes_min(initdate:end)],[c_dwobs_count_bayes_max(initdate:end)],'',22);
    hold off
    set(gca,'fontname','times','FontSize',23)
    title('Real wage','Interpreter','Latex');
    axis([2008 2018 100 106])
    subplot(3,3,6)
    plot(sample,c_inflobs(initdate:end),'Linewidth',4,'LineStyle','-','Color',[0., 0., 0.]);
    hold on 
    irfplot_y_1([sample]',[c_inflobs_count_bayes_mean(initdate:end)],[c_inflobs_count_bayes_min(initdate:end)],[c_inflobs_count_bayes_max(initdate:end)],'',22);
    hold off
    title('Price level','Interpreter','Latex');
    axis([2008 2018 100 114])
    set(gca,'fontname','times','FontSize',23)
    subplot(3,3,7)
 
    plot(sample,4*(srobs_true(initdate:end)+ys(i_srobs_22)),'Linewidth',4,'LineStyle','-','Color',[0., 0., 0.]);
    hold on
    plot(sample,4*(robs_count(initdate:end)+ys(i_srobs_22)),'Linewidth',4,'LineStyle',':','Color',[1, 0.55, 0.00]);
    hold off
    title('Annualised nominal interest rate','Interpreter','Latex');
    axis([2008 2018 -6 6])
    set(gca,'fontname','times','FontSize',23)
 
 set(gcf,'PaperType','<custom>','PaperSize',[20.4 15.25],'PaperPosition',[0.1 0.02158 20.3046 15.2284]);
    print -depsc2 Figure_dsge_sr_all_new.eps
    print -dpdf Figure_dsge_sr_all_new.pdf
 
 
   subplot(1,2,1)
    plot(sample,c_dyobs_4_true(initdate-4:end),'Linewidth',5.5,'LineStyle','-','Color',[0., 0., 0.]);
    hold on
    irfplot_y_2([sample]',[c_dyobs_4_count_bayes_mean(initdate-4:end)],[c_dyobs_4_count_bayes_min(initdate-4:end)],[c_dyobs_4_count_bayes_max(initdate-4:end)],'',22);
    hold off
    title('Output growth','Interpreter','Latex','fontname','times','FontSize',37);
    set(gca,'fontname','times','FontSize',37)
    legend('Observed','Counterfactual','68% confidence interval','Location','SouthEast');
    axis([2008 2018 -7 4])
    subplot(1,2,2)
    plot(sample,c_inflobs_4_true(initdate-4:end),'Linewidth',5.5,'LineStyle','-','Color',[0., 0., 0.]);
     hold on
    irfplot_y_2([sample]',[c_inflobs_4_count_bayes_mean(initdate-4:end)],[c_inflobs_4_count_bayes_min(initdate-4:end)],[c_inflobs_4_count_bayes_max(initdate-4:end)],'',22);
    hold off
    title(' Inflation','Interpreter','Latex','fontname','times','FontSize',37);
    set(gca,'fontname','times','FontSize',37)
    legend('Observed','Counterfactual','68% confidence interval','Location','NorthEast');
    axis([2008 2018 -0.75 2.25])


    
    set(gcf,'PaperType','<custom>','PaperSize',[20.4 15.25],'PaperPosition',[0.1 0.02158 20.3046 15.2284]);
    print -depsc2 Figure_focus_new.eps
    print -dpdf Figure_focus_new.pdf
end;
 
 
//******************************************************
//Counterfactual: Tables
//******************************************************


disp('2014-2017')
dy_diff = c_dyobs_4_true-c_dyobs_4_count_bayes_mean;
meandy = [mean(dy_diff(56:59)) mean(dy_diff(60:63)) mean(dy_diff(64:67)) mean(dy_diff(68:69))];
meandy = mean(meandy)
infl_diff = c_inflobs_4_true-c_inflobs_4_count_bayes_mean;
meaninfl=[mean(infl_diff(56:59)) mean(infl_diff(60:63)) mean(infl_diff(64:67)) mean(infl_diff(68:69))];
meaninfl=mean(meaninfl)

disp('2008-2017')
dy_diff = c_dyobs_4_true-c_dyobs_4_count_bayes_mean;
meandy = [mean(dy_diff(30:34)) mean(dy_diff(35:38)) mean(dy_diff(39:43)) mean(dy_diff(44:47)) mean(dy_diff(48:51)) mean(dy_diff(52:55)) mean(dy_diff(56:59)) mean(dy_diff(60:63)) mean(dy_diff(64:67)) mean(dy_diff(68:69))];
meandy = mean(meandy)
infl_diff = c_inflobs_4_true-c_inflobs_4_count_bayes_mean;
meaninfl=[mean(infl_diff(30:34)) mean(infl_diff(35:38)) mean(infl_diff(39:43)) mean(infl_diff(44:47)) mean(infl_diff(48:51)) mean(infl_diff(52:55)) mean(infl_diff(56:59)) mean(infl_diff(60:63)) mean(infl_diff(64:67)) mean(infl_diff(68:69))];
meaninfl=mean(meaninfl)

disp('2008-2013')
dy_diff = c_dyobs_4_true-c_dyobs_4_count_bayes_mean;
meandy = [mean(dy_diff(30:34)) mean(dy_diff(35:38)) mean(dy_diff(39:43)) mean(dy_diff(44:47)) mean(dy_diff(48:51)) mean(dy_diff(52:55))];
meandy = mean(meandy)
infl_diff = c_inflobs_4_true-c_inflobs_4_count_bayes_mean;
meaninfl=[mean(infl_diff(30:34)) mean(infl_diff(35:38)) mean(infl_diff(39:43)) mean(infl_diff(44:47)) mean(infl_diff(48:51)) mean(infl_diff(52:55))];
meaninfl=mean(meaninfl)
 
 
 
 





