//***********************************************************************************
// "Evaluating the Macroeconomic Effects of the ECB’s Unconventional Monetary Policy"
//
// By Sarah Mouabbi and Jean-Guillaume Sahuc
//
// IRFs: Monetary policy shock
//
//***********************************************************************************



load results_irfs_simul_full;

CI = [0.05,0.5,0.95];

IRFSize = 30;

%divided by 4 because MPshock=1

IR_quant_bench_y_f     = quantile(y_zetar_irf_simul',CI)/4; 
IR_quant_bench_c_f     = quantile(c_zetar_irf_simul',CI)/4; 
IR_quant_bench_x_f     = quantile(x_zetar_irf_simul',CI)/4; 
IR_quant_bench_r_f     = quantile(r_zetar_irf_simul',CI)/4; 
IR_quant_bench_infl_f  = quantile(infl_zetar_irf_simul',CI)/4; 
IR_quant_bench_w_f     = quantile(w_zetar_irf_simul',CI)/4; 
IR_quant_bench_labor_f = quantile(labor_zetar_irf_simul',CI)/4; 

load results_irfs_simul_short;

IR_quant_bench_y_s     = quantile(y_zetar_irf_simul',CI)/4; 
IR_quant_bench_c_s     = quantile(c_zetar_irf_simul',CI)/4; 
IR_quant_bench_x_s     = quantile(x_zetar_irf_simul',CI)/4; 
IR_quant_bench_r_s     = quantile(r_zetar_irf_simul',CI)/4; 
IR_quant_bench_infl_s  = quantile(infl_zetar_irf_simul',CI)/4; 
IR_quant_bench_w_s     = quantile(w_zetar_irf_simul',CI)/4; 
IR_quant_bench_labor_s = quantile(labor_zetar_irf_simul',CI)/4;


subplot(3,3,1) 
irfplot_y_1([1:IRFSize]',[IR_quant_bench_y_s(2,1:IRFSize)'],[IR_quant_bench_y_s(1,1:IRFSize)'],[IR_quant_bench_y_s(3,1:IRFSize)'],'Output',22);
hold on
plot([IR_quant_bench_y_f(2,1:IRFSize)'], 'Linewidth',2.5,'LineStyle','-','Color',[1, 0.55, 0.00],'MarkerEdgeColor',[1, 0.55, 0.00],'MarkerSize',6,'Marker','o');
hold off
subplot(3,3,2) 
irfplot_y_1([1:IRFSize]',[IR_quant_bench_c_s(2,1:IRFSize)'],[IR_quant_bench_c_s(1,1:IRFSize)'],[IR_quant_bench_c_s(3,1:IRFSize)'],'Consumption',22);
hold on
plot([IR_quant_bench_c_f(2,1:IRFSize)'], 'Linewidth',2.5,'LineStyle','-','Color',[1, 0.55, 0.00],'MarkerEdgeColor',[1, 0.55, 0.00],'MarkerSize',6,'Marker','o');
hold off
subplot(3,3,3) 
irfplot_y_1([1:IRFSize]',[IR_quant_bench_x_s(2,1:IRFSize)'],[IR_quant_bench_x_s(1,1:IRFSize)'],[IR_quant_bench_x_s(3,1:IRFSize)'],'Investment',22);
hold on
plot([IR_quant_bench_x_f(2,1:IRFSize)'], 'Linewidth',2.5,'LineStyle','-','Color',[1, 0.55, 0.00],'MarkerEdgeColor',[1, 0.55, 0.00],'MarkerSize',6,'Marker','o');
hold off
subplot(3,3,4) 
irfplot_y_1([1:IRFSize]',[IR_quant_bench_labor_s(2,1:IRFSize)'],[IR_quant_bench_labor_s(1,1:IRFSize)'],[IR_quant_bench_labor_s(3,1:IRFSize)'],'Hours worked',22);
hold on
plot([IR_quant_bench_labor_f(2,1:IRFSize)'], 'Linewidth',2.5,'LineStyle','-','Color',[1, 0.55, 0.00],'MarkerEdgeColor',[1, 0.55, 0.00],'MarkerSize',6,'Marker','o');
hold off
subplot(3,3,5) 
irfplot_y_1([1:IRFSize]',[IR_quant_bench_w_s(2,1:IRFSize)'],[IR_quant_bench_w_s(1,1:IRFSize)'],[IR_quant_bench_w_s(3,1:IRFSize)'],'Real wage',22);
hold on
plot([IR_quant_bench_w_f(2,1:IRFSize)'], 'Linewidth',2.5,'LineStyle','-','Color',[1, 0.55, 0.00],'MarkerEdgeColor',[1, 0.55, 0.00],'MarkerSize',6,'Marker','o');
hold off
subplot(3,3,6) 
irfplot_y_1([1:IRFSize]',[IR_quant_bench_infl_s(2,1:IRFSize)'],[IR_quant_bench_infl_s(1,1:IRFSize)'],[IR_quant_bench_infl_s(3,1:IRFSize)'],'Inflation',22);
hold on
plot([IR_quant_bench_infl_f(2,1:IRFSize)'], 'Linewidth',2.5,'LineStyle','-','Color',[1, 0.55, 0.00],'MarkerEdgeColor',[1, 0.55, 0.00],'MarkerSize',6,'Marker','o');
hold off
subplot(3,3,7) 
irfplot_y_1([1:IRFSize]',[IR_quant_bench_r_s(2,1:IRFSize)'],[IR_quant_bench_r_s(1,1:IRFSize)'],[IR_quant_bench_r_s(3,1:IRFSize)'],'Shadow rate',22);
hold on
plot([IR_quant_bench_r_f(2,1:IRFSize)'], 'Linewidth',2.5,'LineStyle','-','Color',[1, 0.55, 0.00],'MarkerEdgeColor',[1, 0.55, 0.00],'MarkerSize',6,'Marker','o');
hold off

 set(gcf,'PaperType','<custom>','PaperSize',[20.4 15.25],'PaperPosition',[0.1 0.02158 20.3046 15.2284]);
 print -dpdf Figure_irf_mpshock.pdf
 print -depsc2 Figure_irf_mpshock.eps